Introduction
============

.. image:: https://badge.fury.io/py/bottle-rest.png
    :target: http://badge.fury.io/py/bottle-rest

.. image:: https://pypip.in/d/bottle-rest/badge.png
        :target: https://crate.io/packages/bottle-rest?version=latest

This package is used to make easier creating REST applications using
`Bottle <http://bottlepy.org>`_ web framework.

Documentation
-------------

Full module documentation and description can be found at Read the Docs:

- http://bottle-rest.readthedocs.org/